/**
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
import { AxiosInstance, AxiosResponse } from 'axios';
import { ActivityLogApi, ApiKeyApi, ArtistsApi, AudioApi, AuthenticationResult, BrandingApi, ChannelsApi, CollectionApi, ConfigurationApi, DashboardApi, DevicesApi, DisplayPreferencesApi, DlnaApi, DlnaServerApi, DynamicHlsApi, EnvironmentApi, FilterApi, GenresApi, HlsSegmentApi, ImageApi, ImageByNameApi, ImageType, InstantMixApi, ItemLookupApi, ItemRefreshApi, ItemsApi, ItemUpdateApi, LibraryApi, LibraryStructureApi, LiveTvApi, LocalizationApi, MediaInfoApi, MoviesApi, MusicGenresApi, NotificationsApi, PackageApi, PersonsApi, PlaylistsApi, PlaystateApi, PluginsApi, QuickConnectApi, RemoteImageApi, ScheduledTasksApi, SearchApi, SessionApi, StartupApi, StudiosApi, SubtitleApi, SuggestionsApi, SyncPlayApi, SystemApi, TimeSyncApi, TrailersApi, TvShowsApi, UniversalAudioApi, UserApi, UserLibraryApi, UserViewsApi, VideoAttachmentsApi, VideoHlsApi, VideosApi, YearsApi } from './generated-client';
import { ClientInfo, DeviceInfo } from './models';
import { ImageRequestParameters } from './models/api/image-request-parameters';
/** The authorization header field name. */
export declare const AUTHORIZATION_HEADER = "X-Emby-Authorization";
/** Class representing the Jellyfin API. */
export declare class Api {
    basePath: string;
    clientInfo: ClientInfo;
    deviceInfo: DeviceInfo;
    accessToken: string;
    axiosInstance: AxiosInstance;
    constructor(basePath: string, clientInfo: ClientInfo, deviceInfo: DeviceInfo, accessToken?: string, axiosInstance?: AxiosInstance);
    private get configuration();
    /**
     * Convenience method for authenticating a user by name and updating the internal state.
     * @param username The username.
     * @param password The user password if required.
     */
    authenticateUserByName(username: string, password?: string): Promise<AxiosResponse<AuthenticationResult>>;
    /**
     * Convenience method for logging out and updating the internal state.
     */
    logout(): Promise<AxiosResponse<never> | AxiosResponse<void>>;
    /**
     * Get an item image URL.
     * @param itemId The Item ID.
     * @param imageType An optional Image Type (Primary by default).
     * @param params Additional request parameters.
     * @returns The image URL.
     */
    getItemImageUrl(itemId: string, imageType?: ImageType, params?: ImageRequestParameters): string | undefined;
    get authorizationHeader(): string;
    get activityLogApi(): ActivityLogApi;
    get apiKeyApi(): ApiKeyApi;
    get artistsApi(): ArtistsApi;
    get audioApi(): AudioApi;
    get brandingApi(): BrandingApi;
    get channelsApi(): ChannelsApi;
    get collectionApi(): CollectionApi;
    get configurationApi(): ConfigurationApi;
    get dashboardApi(): DashboardApi;
    get devicesApi(): DevicesApi;
    get displayPreferencesApi(): DisplayPreferencesApi;
    get dlnaApi(): DlnaApi;
    get dlnaServerApi(): DlnaServerApi;
    get dynamicHlsApi(): DynamicHlsApi;
    get environmentApi(): EnvironmentApi;
    get filterApi(): FilterApi;
    get genresApi(): GenresApi;
    get hlsSegmentApi(): HlsSegmentApi;
    get imageApi(): ImageApi;
    get imageByNameApi(): ImageByNameApi;
    get instantMixApi(): InstantMixApi;
    get itemLookupApi(): ItemLookupApi;
    get itemRefreshApi(): ItemRefreshApi;
    get itemUpdateApi(): ItemUpdateApi;
    get itemsApi(): ItemsApi;
    get libraryApi(): LibraryApi;
    get libraryStructureApi(): LibraryStructureApi;
    get liveTvApi(): LiveTvApi;
    get localizationApi(): LocalizationApi;
    get mediaInfoApi(): MediaInfoApi;
    get moviesApi(): MoviesApi;
    get musicGenresApi(): MusicGenresApi;
    get notificationsApi(): NotificationsApi;
    get packageApi(): PackageApi;
    get personsApi(): PersonsApi;
    get playlistsApi(): PlaylistsApi;
    get playstateApi(): PlaystateApi;
    get pluginsApi(): PluginsApi;
    get quickConnectApi(): QuickConnectApi;
    get remoteImageApi(): RemoteImageApi;
    get scheduledTasksApi(): ScheduledTasksApi;
    get searchApi(): SearchApi;
    get sessionApi(): SessionApi;
    get startupApi(): StartupApi;
    get studiosApi(): StudiosApi;
    get subtitleApi(): SubtitleApi;
    get suggestionsApi(): SuggestionsApi;
    get syncPlayApi(): SyncPlayApi;
    get systemApi(): SystemApi;
    get timeSyncApi(): TimeSyncApi;
    get trailersApi(): TrailersApi;
    get tvShowsApi(): TvShowsApi;
    get universalAudioApi(): UniversalAudioApi;
    get userApi(): UserApi;
    get userLibraryApi(): UserLibraryApi;
    get userViewsApi(): UserViewsApi;
    get videoAttachmentsApi(): VideoAttachmentsApi;
    get videoHlsApi(): VideoHlsApi;
    get videosApi(): VideosApi;
    get yearsApi(): YearsApi;
}
