"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Api = exports.AUTHORIZATION_HEADER = void 0;
/**
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var axios_1 = __importDefault(require("axios"));
var generated_client_1 = require("./generated-client");
var utils_1 = require("./utils");
// eslint-disable-next-line @typescript-eslint/no-var-requires
var buildFullPath = require('axios/lib/core/buildFullPath');
/** The authorization header field name. */
exports.AUTHORIZATION_HEADER = 'X-Emby-Authorization';
/** Class representing the Jellyfin API. */
var Api = /** @class */ (function () {
    function Api(basePath, clientInfo, deviceInfo, accessToken, axiosInstance) {
        if (accessToken === void 0) { accessToken = ''; }
        if (axiosInstance === void 0) { axiosInstance = axios_1.default; }
        this.basePath = basePath;
        this.clientInfo = clientInfo;
        this.deviceInfo = deviceInfo;
        this.accessToken = accessToken;
        this.axiosInstance = axiosInstance;
    }
    Object.defineProperty(Api.prototype, "configuration", {
        get: function () {
            return new generated_client_1.Configuration({
                basePath: this.basePath,
                apiKey: this.authorizationHeader
            });
        },
        enumerable: false,
        configurable: true
    });
    /**
     * Convenience method for authenticating a user by name and updating the internal state.
     * @param username The username.
     * @param password The user password if required.
     */
    Api.prototype.authenticateUserByName = function (username, password) {
        var _a;
        var _this = this;
        return this.userApi.authenticateUserByName(
        // The axios client does some strange wrapping of the param object
        { authenticateUserByName: { Username: username, Pw: password } }, 
        // The authorization header is required for the request to succeed
        { headers: (_a = {}, _a[exports.AUTHORIZATION_HEADER] = this.authorizationHeader, _a) }).then(function (response) {
            // Update the current token and configuration object
            _this.accessToken = response.data.AccessToken || '';
            return response;
        });
    };
    /**
     * Convenience method for logging out and updating the internal state.
     */
    Api.prototype.logout = function () {
        var _this = this;
        return this.sessionApi.reportSessionEnded().then(function (response) {
            _this.accessToken = '';
            return response;
        });
    };
    /**
     * Get an item image URL.
     * @param itemId The Item ID.
     * @param imageType An optional Image Type (Primary by default).
     * @param params Additional request parameters.
     * @returns The image URL.
     */
    Api.prototype.getItemImageUrl = function (itemId, imageType, params) {
        if (imageType === void 0) { imageType = generated_client_1.ImageType.Primary; }
        if (params === void 0) { params = {}; }
        // TODO: We could probably use ImageApiAxiosParamCreator to make this more robust
        var uri = this.axiosInstance.getUri({
            url: "/Items/".concat(itemId, "/Images/").concat(imageType),
            params: params
        });
        // NOTE: This behavior will probably be the default in axios in the future
        // https://github.com/axios/axios/issues/2468
        return buildFullPath(this.basePath, uri);
    };
    Object.defineProperty(Api.prototype, "authorizationHeader", {
        get: function () {
            return (0, utils_1.getAuthorizationHeader)(this.clientInfo, this.deviceInfo, this.accessToken);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "activityLogApi", {
        get: function () {
            return new generated_client_1.ActivityLogApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "apiKeyApi", {
        get: function () {
            return new generated_client_1.ApiKeyApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "artistsApi", {
        get: function () {
            return new generated_client_1.ArtistsApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "audioApi", {
        get: function () {
            return new generated_client_1.AudioApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "brandingApi", {
        get: function () {
            return new generated_client_1.BrandingApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "channelsApi", {
        get: function () {
            return new generated_client_1.ChannelsApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "collectionApi", {
        get: function () {
            return new generated_client_1.CollectionApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "configurationApi", {
        get: function () {
            return new generated_client_1.ConfigurationApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "dashboardApi", {
        get: function () {
            return new generated_client_1.DashboardApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "devicesApi", {
        get: function () {
            return new generated_client_1.DevicesApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "displayPreferencesApi", {
        get: function () {
            return new generated_client_1.DisplayPreferencesApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "dlnaApi", {
        get: function () {
            return new generated_client_1.DlnaApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "dlnaServerApi", {
        get: function () {
            return new generated_client_1.DlnaServerApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "dynamicHlsApi", {
        get: function () {
            return new generated_client_1.DynamicHlsApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "environmentApi", {
        get: function () {
            return new generated_client_1.EnvironmentApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "filterApi", {
        get: function () {
            return new generated_client_1.FilterApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "genresApi", {
        get: function () {
            return new generated_client_1.GenresApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "hlsSegmentApi", {
        get: function () {
            return new generated_client_1.HlsSegmentApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "imageApi", {
        get: function () {
            return new generated_client_1.ImageApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "imageByNameApi", {
        get: function () {
            return new generated_client_1.ImageByNameApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "instantMixApi", {
        get: function () {
            return new generated_client_1.InstantMixApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "itemLookupApi", {
        get: function () {
            return new generated_client_1.ItemLookupApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "itemRefreshApi", {
        get: function () {
            return new generated_client_1.ItemRefreshApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "itemUpdateApi", {
        get: function () {
            return new generated_client_1.ItemUpdateApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "itemsApi", {
        get: function () {
            return new generated_client_1.ItemsApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "libraryApi", {
        get: function () {
            return new generated_client_1.LibraryApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "libraryStructureApi", {
        get: function () {
            return new generated_client_1.LibraryStructureApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "liveTvApi", {
        get: function () {
            return new generated_client_1.LiveTvApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "localizationApi", {
        get: function () {
            return new generated_client_1.LocalizationApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "mediaInfoApi", {
        get: function () {
            return new generated_client_1.MediaInfoApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "moviesApi", {
        get: function () {
            return new generated_client_1.MoviesApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "musicGenresApi", {
        get: function () {
            return new generated_client_1.MusicGenresApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "notificationsApi", {
        get: function () {
            return new generated_client_1.NotificationsApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "packageApi", {
        get: function () {
            return new generated_client_1.PackageApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "personsApi", {
        get: function () {
            return new generated_client_1.PersonsApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "playlistsApi", {
        get: function () {
            return new generated_client_1.PlaylistsApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "playstateApi", {
        get: function () {
            return new generated_client_1.PlaystateApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "pluginsApi", {
        get: function () {
            return new generated_client_1.PluginsApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "quickConnectApi", {
        get: function () {
            return new generated_client_1.QuickConnectApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "remoteImageApi", {
        get: function () {
            return new generated_client_1.RemoteImageApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "scheduledTasksApi", {
        get: function () {
            return new generated_client_1.ScheduledTasksApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "searchApi", {
        get: function () {
            return new generated_client_1.SearchApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "sessionApi", {
        get: function () {
            return new generated_client_1.SessionApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "startupApi", {
        get: function () {
            return new generated_client_1.StartupApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "studiosApi", {
        get: function () {
            return new generated_client_1.StudiosApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "subtitleApi", {
        get: function () {
            return new generated_client_1.SubtitleApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "suggestionsApi", {
        get: function () {
            return new generated_client_1.SuggestionsApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "syncPlayApi", {
        get: function () {
            return new generated_client_1.SyncPlayApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "systemApi", {
        get: function () {
            return new generated_client_1.SystemApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "timeSyncApi", {
        get: function () {
            return new generated_client_1.TimeSyncApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "trailersApi", {
        get: function () {
            return new generated_client_1.TrailersApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "tvShowsApi", {
        get: function () {
            return new generated_client_1.TvShowsApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "universalAudioApi", {
        get: function () {
            return new generated_client_1.UniversalAudioApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "userApi", {
        get: function () {
            return new generated_client_1.UserApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "userLibraryApi", {
        get: function () {
            return new generated_client_1.UserLibraryApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "userViewsApi", {
        get: function () {
            return new generated_client_1.UserViewsApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "videoAttachmentsApi", {
        get: function () {
            return new generated_client_1.VideoAttachmentsApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "videoHlsApi", {
        get: function () {
            return new generated_client_1.VideoHlsApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "videosApi", {
        get: function () {
            return new generated_client_1.VideosApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Api.prototype, "yearsApi", {
        get: function () {
            return new generated_client_1.YearsApi(this.configuration, undefined, this.axiosInstance);
        },
        enumerable: false,
        configurable: true
    });
    return Api;
}());
exports.Api = Api;
