"use strict";
/**
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DiscoveryService = void 0;
var __1 = require("..");
var utils_1 = require("../utils");
var recommended_server_discovery_1 = require("./recommended-server-discovery");
/** Class used for discovering recommended servers. */
var DiscoveryService = /** @class */ (function () {
    function DiscoveryService(jellyfin) {
        this.jellyfin = jellyfin;
        this.recommendedServerDiscovery = new recommended_server_discovery_1.RecommendedServerDiscovery(this.jellyfin);
    }
    /**
     * Finds the best server from a list of recommended servers by score.
     * @param servers A list of recommended servers.
     * @returns The best scoring recommended server.
     */
    DiscoveryService.prototype.findBestServer = function (servers) {
        // First look for GREAT scores
        var best = servers.find(function (server) { return server.score === __1.RecommendedServerInfoScore.GREAT; });
        // If no GREAT scores, look for GOOD scores
        if (!best) {
            best = servers.find(function (server) { return server.score === __1.RecommendedServerInfoScore.GOOD; });
        }
        // If no GREAT or GOOD scores, look for OK scores
        if (!best) {
            best = servers.find(function (server) { return server.score === __1.RecommendedServerInfoScore.OK; });
        }
        // Do NOT return any BAD scores
        return best;
    };
    /**
     * Gets a list of address candidates url strings
     * from a provided url address string.
     * @param input A server url address string.
     * @returns A list of potential server addresses.
     */
    DiscoveryService.prototype.getAddressCandidates = function (input) {
        return (0, utils_1.getAddressCandidates)(input);
    };
    /**
     * Gets a list of recommended server information from a provided
     * list of possible server addresses.
     * @param servers A list of possible server addresses.
     * @param minimumScore The minimum server score to include in the results.
     * @returns A list of RecommendedServerInfo from the possible server addresses.
     */
    DiscoveryService.prototype.getRecommendedServers = function (servers, minimumScore) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.recommendedServerDiscovery.discover(servers, minimumScore)];
            });
        });
    };
    /**
     * Gets a list of recommended server information from the address
     * candidates of a potential server address.
     * @param input A potential server address.
     * @param minimumScore The minimum server score to include in the results.
     * @returns A list of RecommendedServerInfo from the address candidates.
     */
    DiscoveryService.prototype.getRecommendedServerCandidates = function (input, minimumScore) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.getRecommendedServers(this.getAddressCandidates(input), minimumScore)];
            });
        });
    };
    return DiscoveryService;
}());
exports.DiscoveryService = DiscoveryService;
