"use strict";
/**
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RecommendedServerDiscovery = void 0;
var compare_versions_1 = require("compare-versions");
var __1 = require("..");
/** The expected product name in system info. */
var PRODUCT_NAME = 'Jellyfin Server';
/** Requests taking longer than 3s are considered slow. */
var SLOW_RESPONSE_TIME = 3000;
/** System info request timeout. */
var HTTP_TIMEOUT = 5000;
/** Get the minimum RecommendedServerInfoScore from an array. */
function getMinScore(scores, defaultScore) {
    if (defaultScore === void 0) { defaultScore = __1.RecommendedServerInfoScore.GREAT; }
    return scores.length > 0 ? Math.min.apply(Math, scores) : defaultScore;
}
/** Builds a RecommendedServerInfo from a SystemInfoResult. */
function toRecommendedServerInfo(result) {
    var _a, _b, _c;
    var issues = [];
    var scores = [];
    if (!((_a = result.response) === null || _a === void 0 ? void 0 : _a.data) || result.error) {
        // The response did not return valid data or returned an error
        issues.push(new __1.SystemInfoIssue(result.error));
        scores.push(__1.RecommendedServerInfoScore.BAD);
    }
    else if (result.response.data.ProductName !== PRODUCT_NAME) {
        // The product name returned was invalid
        issues.push(new __1.ProductNameIssue(result.response.data.ProductName));
        scores.push(__1.RecommendedServerInfoScore.BAD);
    }
    var version = (_b = result.response) === null || _b === void 0 ? void 0 : _b.data.Version;
    if (!version) {
        // No version was returned
        issues.push(new __1.VersionMissingIssue());
        scores.push(__1.RecommendedServerInfoScore.BAD);
    }
    else if ((0, compare_versions_1.compare)(version, __1.MINIMUM_VERSION, '<')) {
        // Version is less than the minimum supported
        issues.push(new __1.VersionUnsupportedIssue(version));
        scores.push(__1.RecommendedServerInfoScore.OK);
    }
    else if ((0, compare_versions_1.compare)(version, __1.API_VERSION, '<')) {
        // Version is less than the generated client, but above the minimum
        issues.push(new __1.VersionOutdatedIssue(version));
        scores.push(__1.RecommendedServerInfoScore.GOOD);
    }
    if (result.responseTime > SLOW_RESPONSE_TIME) {
        // Response was slow
        issues.push(new __1.SlowResponseIssue(result.responseTime));
        scores.push(__1.RecommendedServerInfoScore.GOOD);
    }
    return {
        address: result.address,
        responseTime: result.responseTime,
        score: getMinScore(scores),
        issues: issues,
        systemInfo: (_c = result.response) === null || _c === void 0 ? void 0 : _c.data
    };
}
/** Class to discover and evaluate potential servers. */
var RecommendedServerDiscovery = /** @class */ (function () {
    function RecommendedServerDiscovery(jellyfin) {
        this.jellyfin = jellyfin;
    }
    /**
     * Fetches the RecommendedServerInfo for a single server address.
     * @param address The server address.
     * @returns The resulting RecommendedServerInfo.
     */
    RecommendedServerDiscovery.prototype.fetchRecommendedServerInfo = function (address) {
        return __awaiter(this, void 0, void 0, function () {
            var api, startTime;
            return __generator(this, function (_a) {
                api = this.jellyfin.createApi(address);
                startTime = Date.now();
                return [2 /*return*/, api.systemApi.getPublicSystemInfo({ timeout: HTTP_TIMEOUT })
                        .then(function (response) { return ({
                        address: address,
                        response: response,
                        responseTime: Date.now() - startTime
                    }); })
                        .catch(function (error) { return ({
                        address: address,
                        error: error,
                        responseTime: Date.now() - startTime
                    }); })
                        .then(function (result) { return toRecommendedServerInfo(result); })];
            });
        });
    };
    /**
     * Fetches the RecommendedServerInfo for multiple server addresses.
     * @param servers An array of server addresses.
     * @returns The RecommendedServerInfo for each address.
     */
    RecommendedServerDiscovery.prototype.discover = function (servers, minimumScore) {
        if (minimumScore === void 0) { minimumScore = __1.RecommendedServerInfoScore.BAD; }
        return __awaiter(this, void 0, void 0, function () {
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, Promise.all(servers.map(function (server) { return _this.fetchRecommendedServerInfo(server); }))];
                    case 1: return [2 /*return*/, (_a.sent()).filter(function (serverInfo) { return serverInfo.score >= minimumScore; })];
                }
            });
        });
    };
    return RecommendedServerDiscovery;
}());
exports.RecommendedServerDiscovery = RecommendedServerDiscovery;
