/**
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
/** Class representing an issue encountered with a recommended server. */
export declare abstract class RecommendedServerIssue {
}
/** Class representing an issue with the returned product name. */
export declare class ProductNameIssue extends RecommendedServerIssue {
    /** The product name returned in the system information. */
    productName: string | null | undefined;
    constructor(productName?: string | null);
}
/** Class representing a slow response from a server. */
export declare class SlowResponseIssue extends RecommendedServerIssue {
    /** The response time from the server. */
    responseTime: number;
    constructor(responseTime: number);
}
/**
 * Class representing an issue with the system information.
 * This could be due to a networking error or invalid address.
 */
export declare class SystemInfoIssue extends RecommendedServerIssue {
    /** The error generated by the request. */
    error: Error | undefined;
    constructor(error?: Error);
}
/** Class representing the version was missing from system information. */
export declare class VersionMissingIssue extends RecommendedServerIssue {
}
/**
 * Class representing the server version is outdated.
 * (The version is lower than the generated client, but higher than the minimum supported.)
 */
export declare class VersionOutdatedIssue extends RecommendedServerIssue {
    version: string;
    constructor(version: string);
}
/**
 * Class representing the server version is unsupported.
 * (The version is lower than the minimum supported.)
 */
export declare class VersionUnsupportedIssue extends RecommendedServerIssue {
    version: string;
    constructor(version: string);
}
