"use strict";
/**
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.getBrowserDeviceProfile = void 0;
var generated_client_1 = require("../generated-client");
/**
 * Generates a list of subtitle profiles
 * @param {HTMLVideoElement} videoElement - HTML video element to test again
 * @param {DeviceProfileGeneratorOptions} options - Options to pass to the subtitle generator
 * @returns List of subtitle profiles
 */
var getBrowserSubtitleProfiles = function (videoElement, options) {
    var subtitleProfiles = [];
    if (videoElement.textTracks !== null) {
        subtitleProfiles.push({ Format: 'vtt', Method: generated_client_1.SubtitleDeliveryMethod.External });
    }
    if (options === null || options === void 0 ? void 0 : options.ssaExternal) {
        subtitleProfiles.push({ Format: 'ssa', Method: generated_client_1.SubtitleDeliveryMethod.External }, { Format: 'ass', Method: generated_client_1.SubtitleDeliveryMethod.External });
    }
    else {
        subtitleProfiles.push({ Format: 'ssa', Method: generated_client_1.SubtitleDeliveryMethod.Encode }, { Format: 'ass', Method: generated_client_1.SubtitleDeliveryMethod.Encode });
    }
    return subtitleProfiles;
};
/**
 * Generates a device profile based on a few options and the current browser capabilites
 * @exports
 * @param {DeviceProfileGeneratorOptions} options - Options to pass to the different profiles generators
 * @param {HTMLVideoElement} videoElement - Optionnal HTML video element to use, else it'll create one
 * @returns A detected device profile
 */
var getBrowserDeviceProfile = function (options, videoElement) {
    var deviceProfile = {};
    if (!videoElement) {
        videoElement = document.createElement('video');
    }
    deviceProfile.SubtitleProfiles = getBrowserSubtitleProfiles(videoElement, options);
    return deviceProfile;
};
exports.getBrowserDeviceProfile = getBrowserDeviceProfile;
