"use strict";
/**
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseUrl = exports.getDefaultPort = exports.copyUrl = exports.HTTPS_PORT = exports.HTTP_PORT = exports.HTTPS_PROTOCOL = exports.HTTP_PROTOCOL = void 0;
var normalize_url_1 = __importDefault(require("normalize-url"));
/** The http protocol string. */
exports.HTTP_PROTOCOL = 'http:';
/** The https protocol string. */
exports.HTTPS_PROTOCOL = 'https:';
/** The default port for the http protocol. */
exports.HTTP_PORT = 80;
/** The default port for the https protocol. */
exports.HTTPS_PORT = 443;
/**
 * Copies a URL instance.
 * @param original The original URL.
 * @returns A copy of the original URL.
 */
function copyUrl(original) {
    return new URL(original.toString());
}
exports.copyUrl = copyUrl;
/**
 * Returns the default port number for a given protocol.
 * @param protocol The protocol string.
 * @returns The default port number of the protocol.
 */
function getDefaultPort(protocol) {
    if (protocol === exports.HTTP_PROTOCOL)
        return exports.HTTP_PORT;
    if (protocol === exports.HTTPS_PROTOCOL)
        return exports.HTTPS_PORT;
    throw new Error('Unsupported protocol');
}
exports.getDefaultPort = getDefaultPort;
/**
 * Parses a string to a Url object.
 * @param input A string representing a url.
 * @returns The Url object.
 */
function parseUrl(input) {
    if (!(input === null || input === void 0 ? void 0 : input.trim())) {
        throw new Error('Input is required');
    }
    return new URL((0, normalize_url_1.default)(input, { stripWWW: false }));
}
exports.parseUrl = parseUrl;
